@@ -1,24 +1,21 @@
 /*
- * Copyright (c) 1998-2003 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 1998-2004 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -82,6 +79,12 @@ void AppleADBKeyboard::free( void )
 	_keybrdLock = NULL;
     }
 
+	if ( _packetLock )
+	{
+		IOLockFree( _packetLock );
+		_packetLock = NULL;
+	}
+
     if (adbDevice)
     {
 	IORegistryEntry * us;
@@ -106,6 +109,7 @@ bool AppleADBKeyboard::start ( IOService * theNub )
     OSNumber 		*enable_fwd_delete;
 
     _keybrdLock = NULL;
+	_packetLock = NULL;
     _fn_key_invoked_power = false;   //Used by iBook and PowerBooks
     enable_fwd_delete = OSDynamicCast( OSNumber, getProperty("PowerBook fn Foward Delete"));
     if (enable_fwd_delete)
@@ -209,6 +213,7 @@ bool AppleADBKeyboard::start ( IOService * theNub )
     }
 
     _keybrdLock = IOLockAlloc(); 
+	_packetLock = IOLockAlloc();
 
     return super::start(theNub);
 }
@@ -618,6 +623,10 @@ unsigned int	keycode1, keycode2;
 bool		down;
 AbsoluteTime	now;
 
+	//---Since packet is re-entrant, lock around it - [3418665] ---
+	if ( _packetLock )
+		IOLockLock( _packetLock );
+
 keycode1 = *data;
 down = ((keycode1 & 0x80) == 0);
 keycode1 &= 0x7f;
@@ -635,6 +644,9 @@ if( keycode2 != 0xff ) {
 		dispatchKeyboardEvent(keycode2,down,now);
 }
 
+if ( _packetLock )
+	IOLockUnlock( _packetLock );
+
 return kIOReturnSuccess;
 }
 
